package com.iconplus.smartproc.service.instansi;

import com.iconplus.smartproc.helper.model.Pagination;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.projection.InstansiView;
import com.iconplus.smartproc.model.request.InstansiRequest;
import com.iconplus.smartproc.model.request.UsersRequest;
import com.iconplus.smartproc.model.response.GetListInstansiResponse;
import com.iconplus.smartproc.model.response.InstansiResponse;
import com.iconplus.smartproc.repository.InstansiRepository;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class GetListInstansiService implements BaseService<InstansiRequest, GetListInstansiResponse> {

    private InstansiRepository instansiRepository;

    public GetListInstansiService(InstansiRepository instansiRepository) {
        this.instansiRepository = instansiRepository;
    }

    @Override
    public GetListInstansiResponse execute(InstansiRequest input) {
        validateRequest(input);

        List<InstansiResponse> instansiResponseList = new ArrayList<>();
        var listInstansi = instansiRepository.getListInstansi(input.getSearch(), input.getPageable());

        for (InstansiView instansiView : listInstansi) {
            InstansiResponse instansiResponse = InstansiResponse.builder()
                    .id(instansiView.getId())
                    .instansi(instansiView.getInstansi())
                    .alamat(instansiView.getAlamat())
                    .keterangan(instansiView.getKeterangan())
                    .isActive(instansiView.getIsActive())
                    .isDelete(instansiView.getIsDelete())
                    .build();

            instansiResponseList.add(instansiResponse);
        }

        return GetListInstansiResponse.builder()
                .data(instansiResponseList)
                .pagination(Pagination.builder()
                        .pageSize(input.getPageable().getPageSize())
                        .currentPage(input.getPageable().getPageNumber())
                        .totalPages(listInstansi.getTotalPages())
                        .totalRecords(listInstansi.getTotalElements())
                        .isFirstPage(listInstansi.isFirst())
                        .isLastPage(listInstansi.isLast())
                        .build())
                .build();

    }

    private void validateRequest(InstansiRequest input) {
        if (StringUtils.isNotBlank(input.getSearch())) {
            input.setSearch('%'+ input.getSearch().toUpperCase()+'%');
        }
    }
}
